==> nextcloud-12.0.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/gallery/l10n/ko.js <==
OC.L10N.register(
    "gallery",
    {
    "Gallery" : "갤러리",
    "There was a problem reading files from this album" : "앨범에서 파일을 읽는데에 문제가 있습니다.",
    "Aborting preview. Could not find the file" : "미리 보기를 중단합니다. 파일을 찾을 수 없음",
    "Could not move \"{file}\", target exists" : "\"{file}\"을(를) 이동할 수 없음, 대상이 존재함",
    "Could not move \"{file}\"" : "\"{file}\"을(를) 이동할 수 없음",
    "No compatible server found at {remote}" : "{remote}에서 호환 서버를 찾을 수 없음",
    "Invalid server url" : "잘못된 서버 URL",
    "Gallery view" : "갤러리 보기",
    "Could not load the description" : "설명을 불러올 수 없음",
    "Could not load the description: " : "설명을 불러올 수 없음: ",
    "Copyright" : "저작권",
    "Could not load the copyright notice: " : "저작권 공지를 불러올 수 없음: ",
    "Copyright notice" : "저작권 공지",
    "Link to copyright document" : "저작권 문서로 향한 링크",
    "This application may not work properly on your browser." : "이 앱은 현재 사용 중인 웹 브라우저에서 올바르게 작동하지 않을 수 있습니다.",
    "For an improved experience, please install one of the following alternatives" : "향상된 경험을 위하여 다음 중 하나를 설치하십시오",
    "Your browser is not supported!" : "사용 중인 브라우저는 지원되지 않습니다!",
    "please install one of the following alternatives" : "다음 중 하나를 설치하십시오",
    "Album cannot be shown" : "앨범을 표시할 수 없습니다.",
    "No media files found" : "미디어 파일을 찾을 수 없습니다.",
    "Upload pictures in the files app to display them here" : "파일 앱에서 사진을 올리면 여기에 표시됩니다",
    "Upload new files via drag and drop or by using the [+] button above" : "드래그 앤 드롭 또는 위의 [+] 단추를 사용하여 새 파일을 업로드 하십시오.",
    "Configuration error" : "설정 오류",
    "New" : "새로 만들기",
    "Hide Album" : "앨범 숨기기",
    "Could not hide album" : "앨범을 숨길 수 없습니다.",
    "Error loading slideshow template" : "슬라이드 쇼 템플릿을 불러오는 중 오류 발생",
    "<strong>Error!</strong> Could not generate a preview of this file.<br>Please go to the next slide while we remove this image from the slideshow" : "<strong>오류!</strong> 이 파일의 미리보기를 생성 할 수 없습니다.<br>슬라이드 쇼에서 이 이미지를 제거하는 동안 다음 슬라이드로 이동하십시오.",
    "Next" : "다음",
    "Play" : "재생",
    "Pause" : "일시 정지",
    "Previous" : "이전",
    "Close" : "닫기",
    "Download" : "다운로드",
    "Toggle background" : "배경 전환",
    "Delete" : "삭제",
    "Could not create file \"{file}\" because it already exists" : "파일이 이미 존재하므로 \"{file}\"을(를) 만들 수 없음",
    "Could not create file \"{file}\"" : "\"{file}\"을(를) 만들 수 없음",
    "\"{name}\" is an invalid file name." : "\"{name}\"은(는) 잘못된 파일 이름입니다.",
    "File name cannot be empty." : "파일 이름이 비어 있을 수 없습니다.",
    "Upload" : "업로드",
    "Error" : "오류",
    "Error while sharing" : "공유하는 중 오류 발생",
    "Error while unsharing" : "공유 해제하는 중 오류 발생",
    "Error while changing permissions" : "권한 변경하는 중 오류 발생",
    "Shared with you and the group {group} by {owner}" : "{owner} 님이 여러분 및 그룹 {group}와(과) 공유 중",
    "Shared with you by {owner}" : "{owner} 님이 공유 중",
    "Share with users or groups …" : "사용자 및 그룹과 공유...",
    "Share with users, groups or remote users …" : "사용자, 그룹 및 원격 사용자와 공유...",
    "Share" : "공유",
    "Share with people on other servers using their Federated Cloud ID username@example.com/cloud" : "연합 클라우드 ID를 통하여 다른 서버의 사람과 공유 username@example.com/cloud",
    "Share link" : "링크 공유",
    "The public link will expire no later than {days} days after it is created" : "공개 링크를 만든 후 최대 {days}일까지 유지됩니다",
    "Link" : "링크",
    "Password protect" : "암호 보호",
    "Password" : "암호",
    "Choose a password for the public link" : "공개 링크 암호를 입력하십시오",
    "Allow editing" : "편집 허용",
    "Email link to person" : "이메일 주소",
    "Send" : "보내기",
    "Set expiration date" : "만료 날짜 설정",
    "Expiration" : "만료",
    "Expiration date" : "만료 날짜",
    "An error occured. Please try again" : "오류가 발생했습니다. 다시 시도하십시오.",
    "Adding user..." : "사용자 추가 중...",
    "group" : "그룹",
    "remote" : "원격",
    "Resharing is not allowed" : "다시 공유할 수 없습니다",
    "Error while retrieving shares" : "공유를 가져오는 중 오류 발생",
    "Unshare" : "공유 해제",
    "notify by email" : "이메일로 알림",
    "can share" : "공유 가능",
    "can edit" : "편집 가능",
    "access control" : "접근 제어",
    "create" : "생성",
    "change" : "변경",
    "delete" : "삭제",
    "Password protected" : "암호로 보호됨",
    "Error unsetting expiration date" : "만료 날짜 해제 오류",
    "Error setting expiration date" : "만료 날짜 설정 오류",
    "Sending ..." : "전송 중...",
    "Email sent" : "이메일 발송됨",
    "Warning" : "경고",
    "This share is password-protected" : "이 공유는 암호로 보호되어 있습니다",
    "The password is wrong. Try again." : "암호가 잘못되었습니다. 다시 입력해 주십시오.",
    "Sort by date" : "날짜순으로 정렬",
    "Sort by name" : "이름순으로 정렬",
    "Cancel upload" : "업로드 취소",
    "Album information" : "앨범 정보",
    "File list" : "파일 목록",
    "Sorry, this file could not be found." : "이 파일을 찾을 수 없습니다.",
    "Reasons might be:" : "이유는 다음과 같을 수 있습니다:",
    "the wrong file ID was provided" : "잘못된 파일 ID를 받음",
    "the file was removed" : "파일이 삭제됨",
    "the file is corrupt" : "파일이 손상됨",
    "the encryption key is missing" : "암호화 키가 없음",
    "Here is the error message returned by the server: " : "서버에서 반환한 오류 메시지입니다: ",
    "For more information, please contact your friendly Nextcloud administrator." : "더 많은 정보를 확인하려면 Nextcloud 관리자에게 연락하십시오.",
    "Sorry, but the server could not fulfill your request." : "서버에서 요청을 처리할 수 없습니다.",
    "Possible reasons for the problem:" : "문제의 가능한 이유:",
    "a conflicting app was installed" : "충돌하는 앱이 설치됨",
    "a required component is missing or was disconnected" : "필요한 구성 요소가 없거나 연결 해제됨",
    "the filesystem is not readable" : "파일 시스템에서 읽을 수 없음",
    "For more information, please contact your friendly ownCloud administrator." : "더 많은 정보를 보려면 ownCloud 관리자에게 연락하십시오.",
    "Sorry, this link doesn't seem to work anymore." : "이 링크가 더 이상 작동하지 않습니다.",
    "the item was removed" : "항목이 삭제됨",
    "the link has expired" : "링크가 만료됨",
    "sharing is disabled" : "공유가 비활성화됨",
    "For more information, please ask the person who has sent you this link." : "더 많은 정보를 얻으려면 링크를 보낸 사람에게 물어 보십시오.",
    "Add to your Nextcloud" : "Nextcloud에 추가",
    "Picture view" : "사진 보기"
},
"nplurals=1; plural=0;");

==> nextcloud-12.0.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/gallery/l10n/ko.js <==
OC.L10N.register(
    "gallery",
    {
    "Gallery" : "갤러리",
    "There was a problem reading files from this album" : "앨범에서 파일을 읽는데에 문제가 있습니다.",
    "Aborting preview. Could not find the file" : "미리 보기를 중단합니다. 파일을 찾을 수 없음",
    "Could not move \"{file}\", target exists" : "\"{file}\"을(를) 이동할 수 없음, 대상이 존재함",
    "Could not move \"{file}\"" : "\"{file}\"을(를) 이동할 수 없음",
    "No compatible server found at {remote}" : "{remote}에서 호환 서버를 찾을 수 없음",
    "Invalid server url" : "잘못된 서버 URL",
    "Could not load the description" : "설명을 불러올 수 없음",
    "Could not load the description: " : "설명을 불러올 수 없음: ",
    "Copyright" : "저작권",
    "Could not load the copyright notice: " : "저작권 공지를 불러올 수 없음: ",
    "Copyright notice" : "저작권 공지",
    "Link to copyright document" : "저작권 문서로 향한 링크",
    "This application may not work properly on your browser." : "이 앱은 현재 사용 중인 웹 브라우저에서 올바르게 작동하지 않을 수 있습니다.",
    "For an improved experience, please install one of the following alternatives" : "향상된 경험을 위하여 다음 중 하나를 설치하십시오",
    "Your browser is not supported!" : "사용 중인 브라우저는 지원되지 않습니다!",
    "please install one of the following alternatives" : "다음 중 하나를 설치하십시오",
    "Album cannot be shown" : "앨범을 표시할 수 없습니다.",
    "No media files found" : "미디어 파일을 찾을 수 없습니다.",
    "Upload new files via drag and drop or by using the [+] button above" : "드래그 앤 드롭 또는 위의 [+] 단추를 사용하여 새 파일을 업로드 하십시오.",
    "Configuration error" : "설정 오류",
    "New" : "새로 만들기",
    "Hide Album" : "앨범 숨기기",
    "Could not hide album" : "앨범을 숨길 수 없습니다.",
    "Error loading slideshow template" : "슬라이드 쇼 템플릿을 불러오는 중 오류 발생",
    "<strong>Error!</strong> Could not generate a preview of this file.<br>Please go to the next slide while we remove this image from the slideshow" : "<strong>오류!</strong> 이 파일의 미리보기를 생성 할 수 없습니다.<br>슬라이드 쇼에서 이 이미지를 제거하는 동안 다음 슬라이드로 이동하십시오.",
    "Next" : "다음",
    "Play" : "재생",
    "Pause" : "일시 정지",
    "Previous" : "이전",
    "Close" : "닫기",
    "Download" : "다운로드",
    "Toggle background" : "배경 전환",
    "Delete" : "삭제",
    "Could not create file \"{file}\" because it already exists" : "파일이 이미 존재하므로 \"{file}\"을(를) 만들 수 없음",
    "Could not create file \"{file}\"" : "\"{file}\"을(를) 만들 수 없음",
    "\"{name}\" is an invalid file name." : "\"{name}\"은(는) 잘못된 파일 이름입니다.",
    "File name cannot be empty." : "파일 이름이 비어 있을 수 없습니다.",
    "Upload" : "업로드",
    "Error" : "오류",
    "Error while sharing" : "공유하는 중 오류 발생",
    "Error while unsharing" : "공유 해제하는 중 오류 발생",
    "Error while changing permissions" : "권한 변경하는 중 오류 발생",
    "Shared with you and the group {group} by {owner}" : "{owner} 님이 여러분 및 그룹 {group}와(과) 공유 중",
    "Shared with you by {owner}" : "{owner} 님이 공유 중",
    "Share with users or groups …" : "사용자 및 그룹과 공유...",
    "Share with users, groups or remote users …" : "사용자, 그룹 및 원격 사용자와 공유...",
    "Share" : "공유",
    "Share with people on other servers using their Federated Cloud ID username@example.com/cloud" : "연합 클라우드 ID를 통하여 다른 서버의 사람과 공유 username@example.com/cloud",
    "Share link" : "링크 공유",
    "The public link will expire no later than {days} days after it is created" : "공개 링크를 만든 후 최대 {days}일까지 유지됩니다",
    "Link" : "링크",
    "Password protect" : "암호 보호",
    "Password" : "암호",
    "Choose a password for the public link" : "공개 링크 암호를 입력하십시오",
    "Allow editing" : "편집 허용",
    "Email link to person" : "이메일 주소",
    "Send" : "보내기",
    "Set expiration date" : "만료 날짜 설정",
    "Expiration" : "만료",
    "Expiration date" : "만료 날짜",
    "An error occured. Please try again" : "오류가 발생했습니다. 다시 시도하십시오.",
    "Adding user..." : "사용자 추가 중...",
    "group" : "그룹",
    "remote" : "원격",
    "Resharing is not allowed" : "다시 공유할 수 없습니다",
    "Error while retrieving shares" : "공유를 가져오는 중 오류 발생",
    "Unshare" : "공유 해제",
    "notify by email" : "이메일로 알림",
    "can share" : "공유 가능",
    "can edit" : "편집 가능",
    "access control" : "접근 제어",
    "create" : "생성",
    "change" : "변경",
    "delete" : "삭제",
    "Password protected" : "암호로 보호됨",
    "Error unsetting expiration date" : "만료 날짜 해제 오류",
    "Error setting expiration date" : "만료 날짜 설정 오류",
    "Sending ..." : "전송 중...",
    "Email sent" : "이메일 발송됨",
    "Warning" : "경고",
    "This share is password-protected" : "이 공유는 암호로 보호되어 있습니다",
    "The password is wrong. Try again." : "암호가 잘못되었습니다. 다시 입력해 주십시오.",
    "Sort by date" : "날짜순으로 정렬",
    "Sort by name" : "이름순으로 정렬",
    "Cancel upload" : "업로드 취소",
    "Album information" : "앨범 정보",
    "File list" : "파일 목록",
    "Sorry, this file could not be found." : "이 파일을 찾을 수 없습니다.",
    "Reasons might be:" : "이유는 다음과 같을 수 있습니다:",
    "the wrong file ID was provided" : "잘못된 파일 ID를 받음",
    "the file was removed" : "파일이 삭제됨",
    "the file is corrupt" : "파일이 손상됨",
    "the encryption key is missing" : "암호화 키가 없음",
    "Here is the error message returned by the server: " : "서버에서 반환한 오류 메시지입니다: ",
    "For more information, please contact your friendly Nextcloud administrator." : "더 많은 정보를 확인하려면 Nextcloud 관리자에게 연락하십시오.",
    "Sorry, but the server could not fulfill your request." : "서버에서 요청을 처리할 수 없습니다.",
    "Possible reasons for the problem:" : "문제의 가능한 이유:",
    "a conflicting app was installed" : "충돌하는 앱이 설치됨",
    "a required component is missing or was disconnected" : "필요한 구성 요소가 없거나 연결 해제됨",
    "the filesystem is not readable" : "파일 시스템에서 읽을 수 없음",
    "Sorry, this link doesn't seem to work anymore." : "이 링크가 더 이상 작동하지 않습니다.",
    "the item was removed" : "항목이 삭제됨",
    "the link has expired" : "링크가 만료됨",
    "sharing is disabled" : "공유가 비활성화됨",
    "For more information, please ask the person who has sent you this link." : "더 많은 정보를 얻으려면 링크를 보낸 사람에게 물어 보십시오.",
    "Add to your Nextcloud" : "Nextcloud에 추가",
    "Picture view" : "사진 보기",
    "Gallery view" : "갤러리 보기"
},
"nplurals=1; plural=0;");
